==> xmpp-core-common-0.8.2-sources.jar: rocks/xmpp/core/issue137/ObjectFactory.java <==
//
// Diese Datei wurde mit der JavaTM Architecture for XML Binding(JAXB) Reference Implementation, v2.2.11 generiert 
// Siehe <a href="http://java.sun.com/xml/jaxb">http://java.sun.com/xml/jaxb</a> 
// Änderungen an dieser Datei gehen bei einer Neukompilierung des Quellschemas verloren. 
// Generiert: 2019.11.07 um 09:27:55 PM CET 
//


package rocks.xmpp.core.issue137;

import javax.xml.bind.JAXBElement;
import javax.xml.bind.annotation.XmlElementDecl;
import javax.xml.bind.annotation.XmlRegistry;
import javax.xml.namespace.QName;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the rocks.xmpp.core.issue137 package. 
 * <p>An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {

    private final static QName _MyElement_QNAME = new QName("http://testnamespace.com", "myElement");

    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: rocks.xmpp.core.issue137
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link ParentType }
     * 
     */
    public ParentType createParentType() {
        return new ParentType();
    }

    /**
     * Create an instance of {@link ChildType }
     * 
     */
    public ChildType createChildType() {
        return new ChildType();
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link ParentType }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://testnamespace.com", name = "myElement")
    public JAXBElement<ParentType> createMyElement(ParentType value) {
        return new JAXBElement<ParentType>(_MyElement_QNAME, ParentType.class, null, value);
    }

}

==> xmpp-core-common-0.9.0-sources.jar: rocks/xmpp/core/issue137/ObjectFactory.java <==
//
// Diese Datei wurde mit der JavaTM Architecture for XML Binding(JAXB) Reference Implementation, v2.3.2 generiert 
// Siehe <a href="https://javaee.github.io/jaxb-v2/">https://javaee.github.io/jaxb-v2/</a> 
// Änderungen an dieser Datei gehen bei einer Neukompilierung des Quellschemas verloren. 
// Generiert: 2022.09.22 um 12:00:22 AM CEST 
//


package rocks.xmpp.core.issue137;

import javax.xml.bind.JAXBElement;
import javax.xml.bind.annotation.XmlElementDecl;
import javax.xml.bind.annotation.XmlRegistry;
import javax.xml.namespace.QName;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the rocks.xmpp.core.issue137 package. 
 * <p>An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {

    private final static QName _MyElement_QNAME = new QName("http://testnamespace.com", "myElement");

    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: rocks.xmpp.core.issue137
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link ParentType }
     * 
     */
    public ParentType createParentType() {
        return new ParentType();
    }

    /**
     * Create an instance of {@link ChildType }
     * 
     */
    public ChildType createChildType() {
        return new ChildType();
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link ParentType }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link ParentType }{@code >}
     */
    @XmlElementDecl(namespace = "http://testnamespace.com", name = "myElement")
    public JAXBElement<ParentType> createMyElement(ParentType value) {
        return new JAXBElement<ParentType>(_MyElement_QNAME, ParentType.class, null, value);
    }

}
